<?php
/**
 * A unique identifier is defined to store the options in the database and reference them from the theme.
 * By default it uses the theme name, in lowercase and without spaces, but this can be changed if needed.
 * If the identifier changes, it'll appear as if the options have been reset.
 * 
 */

function optionsframework_option_name() {

	// This gets the theme name from the stylesheet (lowercase and without spaces)
	$themename = get_theme_data(get_stylesheet_directory() . '/style.css');
	$themename = $themename['Name'];
	$themename = preg_replace("/\W/", "", strtolower($themename) );
	
	$optionsframework_settings = get_option('optionsframework');
	$optionsframework_settings['id'] = $themename;
	update_option('optionsframework', $optionsframework_settings);
	
	// echo $themename;
}

/**
 * Defines an array of options that will be used to generate the settings page and be saved in the database.
 * When creating the "id" fields, make sure to use all lowercase and no spaces.
 *  
 */

function optionsframework_options() {
	
	// Color schemes
	$color_scheme = array("red" => __('Red', 'delicacy'),"green" => __('Green', 'delicacy'),"blue" => __('Blue', 'delicacy'),"gold" => __('Gold', 'delicacy'),"pink" => __('Pink', 'delicacy'),"orange" =>__('Orange', 'delicacy'));
	$hp_layout = array("1" => __('Показывать весь контент', 'delicacy'),"2" => __('Обрезать полную запись', 'delicacy'));
	$radio = array("0" => __('Нет', 'delicacy'),"1" => __('Да', 'delicacy'));
	// Pull all the categories into an array
	$options_categories = array();  
	$options_categories_obj = get_categories();
	foreach ($options_categories_obj as $category) {
    	$options_categories[$category->cat_ID] = $category->cat_name;
	}
	
	// Pull all the pages into an array
	$options_pages = array();  
	$options_pages_obj = get_pages('sort_column=post_parent,menu_order');
	$options_pages[''] = 'Выберите страницу:';
	foreach ($options_pages_obj as $page) {
    	$options_pages[$page->ID] = $page->post_title;
	}
		
	// If using image radio buttons, define a directory path
	$imagepath =  get_stylesheet_directory_uri() . '/images/';
		
	$options = array();
		
	$options[] = array( "name" => __('Настройки', 'delicacy'),
						"type" => "heading");

	$options[] = array( "name" => __('Цветовая схема', 'delicacy'),
						"desc" => __('Выберите цветовую схему', 'delicacy'),
						"id" => "color_scheme",
						"std" => "one",
						"type" => "select",
						"class" => "mini", //mini, tiny, small
						"options" => $color_scheme);

    $options[] = array( "name" => __('Свой логотип', 'delicacy'),
						"desc" => __('Вы можете загрузить свой логотип', 'delicacy'),
						"id" => "logo_image",
						"type" => "upload");

	$options[] = array( "name" => __('Do You want to use custom favicon?','delicacy'),
						"id" => "favicon_radio",
						"std" => "0",
						"type" => "radio",
						"options" => $radio);					

	$options[] = array( "name" => __('Favicon URL', 'delicacy'),
						"desc" => __('Собственный фавикон favicon.ico', 'delicacy'),
						"id" => "favicon_url",
						"std" => $imagepath . 'favicon.ico',
						"type" => "text");

	$options[] = array( "name" => __('Настройки главной страницы', 'delicacy'),
						"id" => "hp_settings",
						"std" => "1",
						"type" => "select",
						"options" => $hp_layout);

	$options[] = array( "name" => __('Показывать слайдер на главной','delicacy'),
						"id" => "slider_radio",
						"std" => "0",
						"type" => "radio",
						"options" => $radio);

	$options[] = array( "name" => __('Выбрать категории для изображений слайдера', 'delicacy'),
						"desc" => __('Изображение из данной категории будут использоваться в слайдере', 'delicacy'),
						"id" => "slider_category",
						"type" => "select",
						"options" => $options_categories);
						
	return $options;
}